@@ -182,6 +182,7 @@ const completion: Fig.Spec = {
           "bash",
           "elvish",
           "fish",
+          "ksh",
           "nushell",
           "posix",
           "powershell",
@@ -205,8 +206,8 @@ const completion: Fig.Spec = {
           },
         },
         {
-          name: "--all",
-          description: "Show deleted directories",
+          name: ["-a", "--all"],
+          description: "Show unavailable directories",
         },
         {
           name: ["-i", "--interactive"],
