@@ -7,8 +7,9 @@ use crate::db::Database;
 
 impl Run for Import {
     fn run(&self) -> Result<()> {
-        let buffer = fs::read_to_string(&self.path)
-            .with_context(|| format!("could not open database for importing: {}", &self.path.display()))?;
+        let buffer = fs::read_to_string(&self.path).with_context(|| {
+            format!("could not open database for importing: {}", &self.path.display())
+        })?;
 
         let mut db = Database::open()?;
         if !self.merge && !db.dirs().is_empty() {
@@ -30,16 +31,15 @@ fn import_autojump(db: &mut Database, buffer: &str) -> Result<()> {
         if line.is_empty() {
             continue;
         }
-        let mut split = line.splitn(2, '\t');
+        let (rank, path) =
+            line.split_once('\t').with_context(|| format!("invalid entry: {line}"))?;
 
-        let rank = split.next().with_context(|| format!("invalid entry: {line}"))?;
         let mut rank = rank.parse::<f64>().with_context(|| format!("invalid rank: {rank}"))?;
-        // Normalize the rank using a sigmoid function. Don't import actual ranks from autojump,
-        // since its scoring algorithm is very different and might take a while to get normalized.
+        // Normalize the rank using a sigmoid function. Don't import actual ranks from
+        // autojump, since its scoring algorithm is very different and might
+        // take a while to get normalized.
         rank = sigmoid(rank);
 
-        let path = split.next().with_context(|| format!("invalid entry: {line}"))?;
-
         db.add_unchecked(path, rank, 0);
     }
 
@@ -57,7 +57,8 @@ fn import_z(db: &mut Database, buffer: &str) -> Result<()> {
         let mut split = line.rsplitn(3, '|');
 
         let last_accessed = split.next().with_context(|| format!("invalid entry: {line}"))?;
-        let last_accessed = last_accessed.parse().with_context(|| format!("invalid epoch: {last_accessed}"))?;
+        let last_accessed =
+            last_accessed.parse().with_context(|| format!("invalid epoch: {last_accessed}"))?;
 
         let rank = split.next().with_context(|| format!("invalid entry: {line}"))?;
         let rank = rank.parse().with_context(|| format!("invalid rank: {rank}"))?;
