@@ -1,12 +1,12 @@
 use std::io::{self, Write};
 
 use anyhow::{Context, Result};
-use askama::Template;
+use rinja::Template;
 
 use crate::cmd::{Init, InitShell, Run};
 use crate::config;
 use crate::error::BrokenPipeHandler;
-use crate::shell::{self, Opts};
+use crate::shell::{Bash, Elvish, Fish, Ksh, Nushell, Opts, Posix, Powershell, Xonsh, Zsh};
 
 impl Run for Init {
     fn run(&self) -> Result<()> {
@@ -16,14 +16,15 @@ impl Run for Init {
         let opts = &Opts { cmd, hook: self.hook, echo, resolve_symlinks };
 
         let source = match self.shell {
-            InitShell::Bash => shell::Bash(opts).render(),
-            InitShell::Elvish => shell::Elvish(opts).render(),
-            InitShell::Fish => shell::Fish(opts).render(),
-            InitShell::Nushell => shell::Nushell(opts).render(),
-            InitShell::Posix => shell::Posix(opts).render(),
-            InitShell::Powershell => shell::Powershell(opts).render(),
-            InitShell::Xonsh => shell::Xonsh(opts).render(),
-            InitShell::Zsh => shell::Zsh(opts).render(),
+            InitShell::Bash => Bash(opts).render(),
+            InitShell::Elvish => Elvish(opts).render(),
+            InitShell::Fish => Fish(opts).render(),
+            InitShell::Ksh => Ksh(opts).render(),
+            InitShell::Nushell => Nushell(opts).render(),
+            InitShell::Posix => Posix(opts).render(),
+            InitShell::Powershell => Powershell(opts).render(),
+            InitShell::Xonsh => Xonsh(opts).render(),
+            InitShell::Zsh => Zsh(opts).render(),
         }
         .context("could not render template")?;
         writeln!(io::stdout(), "{source}").pipe_exit("stdout")
