@@ -2,19 +2,21 @@ use std::env;
 use std::ffi::OsString;
 use std::path::PathBuf;
 
-use anyhow::{Context, Result};
+use anyhow::{ensure, Context, Result};
 use glob::Pattern;
 
 use crate::db::Rank;
 
 pub fn data_dir() -> Result<PathBuf> {
-    let path = match env::var_os("_ZO_DATA_DIR") {
+    let dir = match env::var_os("_ZO_DATA_DIR") {
         Some(path) => PathBuf::from(path),
         None => dirs::data_local_dir()
             .context("could not find data directory, please set _ZO_DATA_DIR manually")?
             .join("zoxide"),
     };
-    Ok(path)
+
+    ensure!(dir.is_absolute(), "_ZO_DATA_DIR must be an absolute path");
+    Ok(dir)
 }
 
 pub fn echo() -> bool {
@@ -26,7 +28,8 @@ pub fn exclude_dirs() -> Result<Vec<Pattern>> {
         Some(paths) => env::split_paths(&paths)
             .map(|path| {
                 let pattern = path.to_str().context("invalid unicode in _ZO_EXCLUDE_DIRS")?;
-                Pattern::new(pattern).with_context(|| format!("invalid glob in _ZO_EXCLUDE_DIRS: {pattern}"))
+                Pattern::new(pattern)
+                    .with_context(|| format!("invalid glob in _ZO_EXCLUDE_DIRS: {pattern}"))
             })
             .collect(),
         None => {
@@ -47,8 +50,9 @@ pub fn fzf_opts() -> Option<OsString> {
 pub fn maxage() -> Result<Rank> {
     env::var_os("_ZO_MAXAGE").map_or(Ok(10_000.0), |maxage| {
         let maxage = maxage.to_str().context("invalid unicode in _ZO_MAXAGE")?;
-        let maxage =
-            maxage.parse::<u32>().with_context(|| format!("unable to parse _ZO_MAXAGE as integer: {maxage}"))?;
+        let maxage = maxage
+            .parse::<u32>()
+            .with_context(|| format!("unable to parse _ZO_MAXAGE as integer: {maxage}"))?;
         Ok(maxage as Rank)
     })
 }
