@@ -10,7 +10,7 @@ pub struct Opts<'a> {
 
 macro_rules! make_template {
     ($name:ident, $path:expr) => {
-        #[derive(::std::fmt::Debug, ::askama::Template)]
+        #[derive(::std::fmt::Debug, ::rinja::Template)]
         #[template(path = $path)]
         pub struct $name<'a>(pub &'a self::Opts<'a>);
 
@@ -26,6 +26,7 @@ macro_rules! make_template {
 make_template!(Bash, "bash.txt");
 make_template!(Elvish, "elvish.txt");
 make_template!(Fish, "fish.txt");
+make_template!(Ksh, "ksh.txt");
 make_template!(Nushell, "nushell.txt");
 make_template!(Posix, "posix.txt");
 make_template!(Powershell, "powershell.txt");
@@ -35,8 +36,8 @@ make_template!(Zsh, "zsh.txt");
 #[cfg(feature = "nix-dev")]
 #[cfg(test)]
 mod tests {
-    use askama::Template;
     use assert_cmd::Command;
+    use rinja::Template;
     use rstest::rstest;
     use rstest_reuse::{apply, template};
 
@@ -70,7 +71,7 @@ mod tests {
         let source = Bash(&opts).render().unwrap();
 
         Command::new("shellcheck")
-            .args(["--enable", "all", "--shell", "bash", "-"])
+            .args(["--enable=all", "-"])
             .write_stdin(source)
             .assert()
             .success()
@@ -85,7 +86,7 @@ mod tests {
         source.push('\n');
 
         Command::new("shfmt")
-            .args(["-d", "-s", "-ln", "bash", "-i", "4", "-ci", "-"])
+            .args(["--diff", "--indent=4", "--language-dialect=bash", "--simplify", "-"])
             .write_stdin(source)
             .assert()
             .success()
@@ -96,16 +97,31 @@ mod tests {
     #[apply(opts)]
     fn elvish_elvish(cmd: Option<&str>, hook: InitHook, echo: bool, resolve_symlinks: bool) {
         let opts = Opts { cmd, hook, echo, resolve_symlinks };
-        let mut source = String::new();
+        let mut source = String::default();
 
-        // Filter out lines using edit:*, since those functions are only available in the
-        // interactive editor.
-        for line in Elvish(&opts).render().unwrap().split('\n').filter(|line| !line.contains("edit:")) {
+        // Filter out lines using edit:*, since those functions are only available in
+        // the interactive editor.
+        for line in Elvish(&opts).render().unwrap().lines().filter(|line| !line.contains("edit:")) {
             source.push_str(line);
             source.push('\n');
         }
 
-        Command::new("elvish").args(["-c", &source, "-norc"]).assert().success().stdout("").stderr("");
+        Command::new("elvish")
+            .args(["-c", &source, "-norc"])
+            .assert()
+            .success()
+            .stdout("")
+            .stderr("");
+    }
+
+    #[apply(opts)]
+    fn fish_no_builtin_abbr(cmd: Option<&str>, hook: InitHook, echo: bool, resolve_symlinks: bool) {
+        let opts = Opts { cmd, hook, echo, resolve_symlinks };
+        let source = Fish(&opts).render().unwrap();
+        assert!(
+            !source.contains("builtin abbr"),
+            "`builtin abbr` does not work on older versions of Fish"
+        );
     }
 
     #[apply(opts)]
@@ -143,6 +159,42 @@ mod tests {
             .stderr("");
     }
 
+    #[apply(opts)]
+    fn ksh_ksh(cmd: Option<&str>, hook: InitHook, echo: bool, resolve_symlinks: bool) {
+        let opts = Opts { cmd, hook, echo, resolve_symlinks };
+        let source = Ksh(&opts).render().unwrap();
+        Command::new("ksh").args(["-n", "-c", &source]).assert().success().stdout("").stderr("");
+    }
+
+    #[apply(opts)]
+    fn ksh_shellcheck(cmd: Option<&str>, hook: InitHook, echo: bool, resolve_symlinks: bool) {
+        let opts = Opts { cmd, hook, echo, resolve_symlinks };
+        let source = Ksh(&opts).render().unwrap();
+
+        Command::new("shellcheck")
+            .args(["--enable=all", "-"])
+            .write_stdin(source)
+            .assert()
+            .success()
+            .stdout("")
+            .stderr("");
+    }
+
+    #[apply(opts)]
+    fn ksh_shfmt(cmd: Option<&str>, hook: InitHook, echo: bool, resolve_symlinks: bool) {
+        let opts = Opts { cmd, hook, echo, resolve_symlinks };
+        let mut source = Ksh(&opts).render().unwrap();
+        source.push('\n');
+
+        Command::new("shfmt")
+            .args(["--diff", "--indent=4", "--language-dialect=mksh", "--simplify", "-"])
+            .write_stdin(source)
+            .assert()
+            .success()
+            .stdout("")
+            .stderr("");
+    }
+
     #[apply(opts)]
     fn nushell_nushell(cmd: Option<&str>, hook: InitHook, echo: bool, resolve_symlinks: bool) {
         let opts = Opts { cmd, hook, echo, resolve_symlinks };
@@ -151,8 +203,12 @@ mod tests {
         let tempdir = tempfile::tempdir().unwrap();
         let tempdir = tempdir.path();
 
-        let assert =
-            Command::new("nu").env("HOME", tempdir).args(["--commands", &source]).assert().success().stderr("");
+        let assert = Command::new("nu")
+            .env("HOME", tempdir)
+            .args(["--commands", &source])
+            .assert()
+            .success()
+            .stderr("");
 
         if opts.hook != InitHook::Pwd {
             assert.stdout("");
@@ -179,19 +235,20 @@ mod tests {
         let opts = Opts { cmd, hook, echo, resolve_symlinks };
         let source = Posix(&opts).render().unwrap();
 
-        let assert = Command::new("dash").args(["-e", "-u", "-c", &source]).assert().success().stderr("");
+        let assert =
+            Command::new("dash").args(["-e", "-u", "-c", &source]).assert().success().stderr("");
         if opts.hook != InitHook::Pwd {
             assert.stdout("");
         }
     }
 
     #[apply(opts)]
-    fn posix_shellcheck_(cmd: Option<&str>, hook: InitHook, echo: bool, resolve_symlinks: bool) {
+    fn posix_shellcheck(cmd: Option<&str>, hook: InitHook, echo: bool, resolve_symlinks: bool) {
         let opts = Opts { cmd, hook, echo, resolve_symlinks };
         let source = Posix(&opts).render().unwrap();
 
         Command::new("shellcheck")
-            .args(["--enable", "all", "--shell", "sh", "-"])
+            .args(["--enable=all", "-"])
             .write_stdin(source)
             .assert()
             .success()
@@ -206,7 +263,7 @@ mod tests {
         source.push('\n');
 
         Command::new("shfmt")
-            .args(["-d", "-s", "-ln", "posix", "-i", "4", "-ci", "-"])
+            .args(["--diff", "--indent=4", "--language-dialect=posix", "--simplify", "-"])
             .write_stdin(source)
             .assert()
             .success()
@@ -234,7 +291,12 @@ mod tests {
         let mut source = Xonsh(&opts).render().unwrap();
         source.push('\n');
 
-        Command::new("black").args(["--check", "--diff", "-"]).write_stdin(source).assert().success().stdout("");
+        Command::new("black")
+            .args(["--check", "--diff", "-"])
+            .write_stdin(source)
+            .assert()
+            .success()
+            .stdout("");
     }
 
     #[apply(opts)]
@@ -283,7 +345,7 @@ mod tests {
 
         // ShellCheck doesn't support zsh yet: https://github.com/koalaman/shellcheck/issues/809
         Command::new("shellcheck")
-            .args(["--enable", "all", "--shell", "bash", "-"])
+            .args(["--enable=all", "-"])
             .write_stdin(source)
             .assert()
             .success()
